@@ -37,7 +37,7 @@ class NBApi(FastAPI):
             request.state.ctx[KEY_AUTH] = request.headers['authorization']
             resp = await call_next(request)
             c.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.ctx[KEY_CID]).inc()
-            g.labels(path=request.url.path, status_code=resp.status_code, cid=getattr(request.state, KEY_CID)).set(time.time() - ts)
+            g.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.ctx[KEY_CID]).set(time.time() - ts)
             return resp
 
         self.middleware('http')(http_middleware)
