@@ -26,6 +26,6 @@ def error(ctx, content):
 
 
 def _log(ctx, level, content):
-    cid = getattr(ctx, KEY_CID, 'unknown')
-    uid = getattr(ctx, KEY_ID, 'unknown')
+    cid = ctx.get(KEY_CID, 'unknown')
+    uid = ctx.get(KEY_ID, 'unknown')
     _loggers.get(level, logging.info)(f'[{cid}|{uid}]: {content}')
